import React, { useEffect, useState } from 'react';
import {
  SafeAreaView,
  ScrollView,
  StyleSheet,
} from 'react-native';

import TUIChatEngine, {
  TUIStore,
  StoreName,
  TUIGroupService,
  TUITranslateService,
} from '@tencentcloud/chat-uikit-engine';

import { Header } from './Header';
import { GroupSetting } from './GroupSetting';

interface IChatSettingProps {
  navigateBack?: () => void;
  navigateToChat?: () => void;
  navigateToConversationList?: () => void;
}

function UnMemoizedChatSetting(props: IChatSettingProps): React.ReactElement {
  const { navigateBack, navigateToChat, navigateToConversationList } = props;
  const [isGroupChat, setIsGroupChat] = useState<boolean>(false);

  useEffect(() => {
    TUIStore.watch(StoreName.CONV, {
      currentConversationID: onCurrentConversationIDUpdated,
    });
    return () => {
      TUIStore.unwatch(StoreName.CONV, {
        currentConversationID: onCurrentConversationIDUpdated,
      });
    };
  }, []);

  const onCurrentConversationIDUpdated = (conversationID: string) => {
    if (conversationID && conversationID.startsWith(TUIChatEngine.TYPES.CONV_GROUP)) {
      const groupID = conversationID.replace(TUIChatEngine.TYPES.CONV_GROUP, '');
      TUIGroupService.switchGroup(groupID);
      setIsGroupChat(true);
    }
  };

  return (
    <SafeAreaView style={styles.chatSettingContainer}>
      <Header
        title={TUITranslateService.t('ChatSetting.GROUP_DETAILS')}
        navigateBack={navigateBack}
      />
      <ScrollView showsVerticalScrollIndicator={false}>
        {isGroupChat && (
          <GroupSetting
            navigateToChat={navigateToChat}
            navigateToConversationList={navigateToConversationList}
          />
        )}
      </ScrollView>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  chatSettingContainer: {
    backgroundColor: '#FFFFFF',
  },
});

export const ChatSetting = React.memo(UnMemoizedChatSetting) as typeof UnMemoizedChatSetting;
