import React, { useState, useEffect } from 'react';
import { SafeAreaView, StyleSheet } from 'react-native';

import TUIChatEngine, { StoreName, TUIGroupService, TUIStore, TUITranslateService } from '@tencentcloud/chat-uikit-engine';

import { RadioList } from '../../../../RadioList';

import { USER_AVATAR_DEFAULT } from '../../../../../constant';

interface IMemberListProps {
  title: string;
  groupID: string;
  filterMySelf?: boolean;
  radioPos?: string;
  onClose: () => void;
  onConfirm?: (data: Record<string, string | number>) => void;
}

export const MemberList = (props: IMemberListProps) => {
  const {
    title,
    groupID,
    filterMySelf,
    radioPos,
    onClose,
    onConfirm,
  } = props;

  const [memberList, setMemberList] = useState<any>([]);

  const myProfile = TUIStore.getData(StoreName.USER, 'userProfile');

  useEffect(() => {
    TUIStore.watch(StoreName.GRP, {
      currentGroupMemberList: onCurrentGroupMemberListUpdated,
    });
    return () => {
      TUIStore.unwatch(StoreName.GRP, {
        currentGroupMemberList: onCurrentGroupMemberListUpdated,
      });
    };
  }, []);

  const onCurrentGroupMemberListUpdated = (_memberList: Record<string, any>[]) => {
    setMemberList(_memberList);
  };

  const _onConfirm = (data: Record<string, any>) => {
    onConfirm && onConfirm(data);
  };

  const handelDataList = () => {
    let dataList = memberList;

    // filter myself
    if (filterMySelf) {
      dataList = memberList.filter((item: Record<string, any>) => item.userID !== myProfile.userID);
    }

    // get radioList data
    dataList = dataList.map((item: Record<string, any>) => {
      let mark = null;
      if (item.role === TUIChatEngine.TYPES.GRP_MBR_ROLE_OWNER) {
        mark = TUITranslateService.t('ChatSetting.OWNER');
      }
      if (item.role === TUIChatEngine.TYPES.GRP_MBR_ROLE_ADMIN) {
        mark = TUITranslateService.t('ChatSetting.ADMIN');
      }
      return {
        userID: item.userID,
        icon: item.avatar || USER_AVATAR_DEFAULT,
        text: item.nick || item.userID,
        mark,
      };
    });
    return dataList;
  };

  const loadMoreData = () => {
    const isCompleted = TUIStore.getData(StoreName.GRP, 'isCompleted');
    if (!isCompleted) {
      try {
        TUIGroupService.getGroupMemberList({ groupID });
      } catch (error) {}
    }
  };

  return (
    <SafeAreaView>
      <RadioList
        title={title}
        dataList={handelDataList()}
        radioPos={radioPos}
        onClose={onClose}
        onConfirm={_onConfirm}
        loadMoreData={loadMoreData}
        textStyle={styles.textStyle}
      />
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  textStyle: {
    width: 100,
  },
});
